
## CATO-CLI - query.site.secondaryAzureVSocket:
[Click here](https://api.catonetworks.com/documentation/#query-query.site.secondaryAzureVSocket) for documentation on this operation.

### Usage for query.site.secondaryAzureVSocket:

```bash
catocli query site secondaryAzureVSocket -h

catocli query site secondaryAzureVSocket <json>

catocli query site secondaryAzureVSocket --json-file query.site.secondaryAzureVSocket.json

catocli query site secondaryAzureVSocket '{"socketId":"id"}'

catocli query site secondaryAzureVSocket '{
    "socketId": "id"
}'
```

#### Operation Arguments for query.site.secondaryAzureVSocket ####

`accountId` [ID] - (required) N/A    
`socketId` [ID] - (required) N/A    
